@@ -2,11 +2,11 @@ import re
 
 
 def get_domain_name(url):
-    domain_name_pat = re.compile(r'www\.([\w\d\s\-\.]+)\/')
+    domain_name_pat = re.compile(r'.*\://(?:www.)?([^\/]+)')
     extract = domain_name_pat.findall(url)
 
     if len(extract) == 0:
-        raise ValueError
+        raise ValueError("Invalid domain name !! We couldn't parse domain name from your given url")
     else:
         return extract[0]
 
@@ -23,10 +23,10 @@ class BaseSwitch(object):
     switcher = {}
 
     @classmethod
-    def get_data(self, url):
+    def get_data(self, url, raise_exception=False):
         domain = get_domain_name(url)
 
         if not domain in self.switcher:
             raise NotImplementedError(url)
-        return self.switcher.get(domain)(url)
+        return self.switcher.get(domain)(url, raise_exception)
 
